[Koha-cvs] koha search.marc/search.pl serials/acqui-search...

Antoine Farnault antoine at koha-fr.org
Fri Jul 21 11:36:42 CEST 2006


CVSROOT:	/sources/koha
Module name:	koha
Changes by:	Antoine Farnault <toins>	06/07/21 09:36:42

Modified files:
	search.marc    : search.pl 
	serials        : acqui-search.pl acqui-search-result.pl 

Log message:
	subs renamed & POD added

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/koha/search.marc/search.pl?cvsroot=koha&r1=1.31&r2=1.32
http://cvs.savannah.gnu.org/viewcvs/koha/serials/acqui-search.pl?cvsroot=koha&r1=1.2&r2=1.3
http://cvs.savannah.gnu.org/viewcvs/koha/serials/acqui-search-result.pl?cvsroot=koha&r1=1.2&r2=1.3

Patches:
Index: search.marc/search.pl
===================================================================
RCS file: /sources/koha/koha/search.marc/search.pl,v
retrieving revision 1.31
retrieving revision 1.32
diff -u -b -r1.31 -r1.32
--- search.marc/search.pl	4 Jul 2006 14:36:52 -0000	1.31
+++ search.marc/search.pl	21 Jul 2006 09:36:42 -0000	1.32
@@ -353,7 +353,7 @@
 	my @branches;
 	my @select_branch;
 	my %select_branches;
-	my $branches=getbranches();
+	my $branches=GetBranches();
 	my @branchloop;
 	foreach my $thisbranch (sort keys %$branches) {
 # 		my $selected = 1 if $thisbranch eq $branch;

Index: serials/acqui-search.pl
===================================================================
RCS file: /sources/koha/koha/serials/acqui-search.pl,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- serials/acqui-search.pl	7 Jul 2006 09:05:23 -0000	1.2
+++ serials/acqui-search.pl	21 Jul 2006 09:36:42 -0000	1.3
@@ -17,7 +17,7 @@
 # Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 # Suite 330, Boston, MA  02111-1307 USA
 
-# $Id: acqui-search.pl,v 1.2 2006/07/07 09:05:23 toins Exp $
+# $Id: acqui-search.pl,v 1.3 2006/07/21 09:36:42 toins Exp $
 
 use strict;
 use CGI;
@@ -45,7 +45,9 @@
 my $sthtemp = $dbh->prepare("Select flags, branchcode from borrowers where borrowernumber = ?");
 $sthtemp->execute($loggedinuser);
 my ($flags, $homebranch)=$sthtemp->fetchrow;
-my ($count, at results)=bookfunds($homebranch);
+my @results=GetBookFunds($homebranch);
+my $count = scalar(@results);
+
 my $classlist='';
 my $total=0;
 my $totspent=0;
@@ -53,7 +55,7 @@
 my $totavail=0;
 my @loop_budget = ();
 for (my $i=0;$i<$count;$i++){
-	my ($spent,$comtd)=bookfundbreakdown($results[$i]->{'bookfundid'});
+	my ($spent,$comtd)=GetBookFundBreakdown($results[$i]->{'bookfundid'});
 	my $avail=$results[$i]->{'budgetamount'}-($spent+$comtd);
 	my %line;
 	$line{bookfundname} = $results[$i]->{'bookfundname'};
@@ -68,7 +70,9 @@
 	$totavail+=$avail;
 }
 #currencies
-my ($count,$rates)=getcurrencies();
+my $rates=GetCurrencies();
+my $count = scalar @$rates;
+
 my @loop_currency = ();
 for (my $i=0;$i<$count;$i++){
 	my %line;

Index: serials/acqui-search-result.pl
===================================================================
RCS file: /sources/koha/koha/serials/acqui-search-result.pl,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- serials/acqui-search-result.pl	7 Jul 2006 09:05:23 -0000	1.2
+++ serials/acqui-search-result.pl	21 Jul 2006 09:36:42 -0000	1.3
@@ -20,7 +20,25 @@
 # Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 # Suite 330, Boston, MA  02111-1307 USA
 
-# $Id: acqui-search-result.pl,v 1.2 2006/07/07 09:05:23 toins Exp $
+# $Id: acqui-search-result.pl,v 1.3 2006/07/21 09:36:42 toins Exp $
+
+=head1 NAME
+
+acqui-search-result.pl
+
+=head1 DESCRIPTION
+ TODO
+ 
+=head1 PARAMETERS
+
+=over 4
+
+=item supplier
+
+=back
+
+=cut
+
 
 use strict;
 use C4::Auth;
@@ -44,13 +62,16 @@
 			     });
 
 my $supplier=$query->param('supplier');
-my ($count, at suppliers)=bookseller($supplier);
+my @suppliers = GetBookSeller($supplier);
+my $count = scalar @suppliers;
 
 #build reult page
 my $toggle=0;
 my @loop_suppliers;
 for (my $i=0; $i<$count; $i++) {
-	my ($ordcount,$orders)=getorders($suppliers[$i]->{'id'});
+    my $orders = GetOrders($suppliers[$i]->{'id'});
+    my $ordcount = scalar @$orders;
+    
 	my %line;
 	if ($toggle==0){
 		$line{even}=1;
@@ -44,13 +62,16 @@
 
-#build reult page
+#build result page
 my $toggle=0;
 my @loop_suppliers;





More information about the Koha-cvs mailing list